import logging
import sys

from pathlib import Path

from .constants import LOGGING_FORMAT


def setup_logging(logfile: Path) -> None:
    """Setup logging with file and stderr handlers.
    
    Args:
        logfile: Path to the log file.
    """
    logfile.parent.mkdir(parents=True, exist_ok=True)

    logger = logging.getLogger()
    logger.setLevel(logging.INFO)

    file_handler = logging.FileHandler(logfile)
    file_handler.setLevel(logging.INFO)
    file_handler.setFormatter(logging.Formatter(LOGGING_FORMAT))
    logger.addHandler(file_handler)

    stderr_handler = logging.StreamHandler(sys.stderr)
    stderr_handler.setLevel(logging.WARNING)
    stderr_handler.setFormatter(logging.Formatter("%(levelname)s: %(message)s"))
    logger.addHandler(stderr_handler)



from pathlib import Path

LOGGING_FORMAT = "%(asctime)s - %(levelname)s - %(message)s"

ORG = "baylorgenetics"
API_VERSION = "7.0"

DEFAULT_ENV_FILE = Path("~/.config/jps-ado-pr-utils/.env").expanduser()
